@@ -127,7 +127,7 @@ class Node:
 
 
 @pytest.mark.skipif(
-    settings._current_profile == "crosshair",
+    settings.get_current_profile_name() == "crosshair",
     reason="takes ~11 mins; datastructure explosion: https://github.com/pschanely/hypothesis-crosshair/issues/27",
 )
 @given(st.builds(Node))
@@ -200,6 +200,14 @@ def has_posonly_args(x, /, y):
     pass
 
 
+@pytest.mark.xfail(
+    settings.get_current_profile_name() == "threading",
+    reason=(
+        "dynamic @example applications modify the shared "
+        "has_posonly_args.hypothesis._given_kwargs."
+    ),
+    strict=False,
+)
 def test_example_argument_validation():
     example(y=None)(has_posonly_args)(1)  # Basic case is OK
 
